@@ -1,3 +1,4 @@
+from django.contrib import admin
 from django.urls import path, include
 from rest_framework import routers
 
@@ -7,6 +8,9 @@ router = routers.DefaultRouter()
 router.registry.extend(model_router.registry)
 
 urlpatterns = [
+    # django Admin
+    path('admin/', admin.site.urls),
+
     # REST Viewsets
     path('api/v1/', include(router.urls)),
 ]
